<?php
namespace Teknisa\CADSUP\Controllers;

use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Error;

class FornecedorNaoAtendeController extends \Teknisa\GER\Controllers\TeknisaCrud 
{

    protected $dataSourceName = "fornecedornaoatende";
	protected $connection;

	public function __construct($crudService, ParameterBag $parameterBag, $connection) 
	{
        $this->crudService = $crudService;
        $this->parameterBag = $parameterBag;
        $this->con = $connection;
    }
    
    private function verifyFornecedorAtendeFilial($rows)
    {
    	$query = "SELECT COUNT(1) CONTADOR
					FROM FILIAL 
				   WHERE (FILIAL.CDREGIAO = :P_CDREGIAO)
				     AND ((EXISTS (SELECT CDFORNECED 
				    				 FROM REFORFIL 
				    				WHERE REFORFIL.CDFORNECED = :P_CDFORNECED
				    				  AND REFORFIL.CDFILIAL   = FILIAL.CDFILIAL
				    				  AND REFORFIL.CDPERIENTR IS NOT NULL)) OR 
				    	 (NOT EXISTS (SELECT CDFORNECED 
				    					FROM REFORFIL
				    				   WHERE REFORFIL.CDFORNECED = :P_CDFORNECED
				    				     AND REFORFIL.CDFILIAL   = FILIAL.CDFILIAL)))";
		$stmt = $this->con->prepare($query);
		$stmt->execute(array(
			"P_CDREGIAO" => $rows[0]['CDREGIAO'],
			"P_CDFORNECED" => $rows[0]['CDFORNECED']
		));
		
		return $stmt->fetchAll();
    }
    
    private function verifyFornecedorCadastrado($rows)
    {
    	$query = "SELECT COUNT(1) CONTADOR
					FROM REFOREG
				   WHERE CDREGIAO	= :P_CDREGIAO
				     AND CDFORNECED = :P_CDFORNECED";
		$stmt = $this->con->prepare($query);
		$stmt->execute(array(
			"P_CDREGIAO" => $rows[0]['CDREGIAO'],
			"P_CDFORNECED" => $rows[0]['CDFORNECED']
		));
		
		return $stmt->fetchAll();
    }
	
	public function save(DTO\Request $request, DTO\Response $response)
	{
		$rows = $request->getDataSet()->getRows();
		
		$fornecedorNaoAtendeFilial = $this->verifyFornecedorAtendeFilial($rows);
		$fornecedorJaCadastrado = $this->verifyFornecedorCadastrado($rows);
		
		if($fornecedorNaoAtendeFilial[0]['CONTADOR'] > 0 ){
			$response->setError(new Error("fornecedorNaoAtendeFilial", 500));
		} else if($fornecedorJaCadastrado[0]['CONTADOR'] > 0 ){
			$response->setError(new Error("fornecedorJaCadastrado", 500));
		} else {
			try {
				$query = 'INSERT INTO REFOREG (CDREGIAO, CDFORNECED) VALUES (:CDREGIAO, :CDFORNECED)';
				$stmt = $this->con->prepare($query);
				$stmt->execute(array(
					"CDREGIAO" => $request->getDataSet()->getRows()[0]['CDREGIAO'],
					"CDFORNECED" => $request->getDataSet()->getRows()[0]['CDFORNECED']
				));
			} catch (\Exception $e) {
				$response->setError(new Error($e->getMessage(), 500));
			}
		}
	}
	
	public function delete(DTO\Request $request, DTO\Response $response)
	{
		$row = $request->getRow();
		try {
			$query = "DELETE FROM REFOREG WHERE CDREGIAO = :CDREGIAO AND CDFORNECED = :CDFORNECED";
			$stmt = $this->con->prepare($query);
			$stmt->execute(array(
				"CDREGIAO" => $request->getRow()['CDREGIAO'],
				"CDFORNECED" => $request->getRow()['CDFORNECED']
			));
		} catch (\Exception $e) {
			$response->setError(new Error($e->getMessage(), 500));
		}
	}
}